==> nextcloud-12.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/dav/l10n/sv.js <==
OC.L10N.register(
    "dav",
    {
    "Calendar" : "Kalender",
    "Todos" : "Uppgifter",
    "Personal" : "Privat",
    "{actor} created calendar {calendar}" : "{actor} skapade kalender {calendar}",
    "You created calendar {calendar}" : "Du skapade kalender {calendar}",
    "{actor} deleted calendar {calendar}" : "{actor} raderade kalender {calendar}",
    "You deleted calendar {calendar}" : "Du raderade kalender {calendar}",
    "{actor} updated calendar {calendar}" : "{actor} uppdaterade kalender {calendar}",
    "You updated calendar {calendar}" : "Du uppdaterade kalender {calendar}",
    "{actor} shared calendar {calendar} with you" : "{actor} delade kalender {calendar} med dig",
    "You shared calendar {calendar} with {user}" : "Du delade kalender {calendar} med {user}",
    "{actor} shared calendar {calendar} with {user}" : "{actor} delade kalender {calendar} med {user}",
    "{actor} unshared calendar {calendar} from you" : "{actor} slutade dela kalender {calendar} med dig",
    "You unshared calendar {calendar} from {user}" : "Du slutade dela kalender {calendar} med {user}",
    "{actor} unshared calendar {calendar} from {user}" : "{actor} slutade dela kalender {calendar} med {user}",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} slutade dela kalender {calendar} med sig själv",
    "You shared calendar {calendar} with group {group}" : "Du delade kalender {calendar} med grupp {group}",
    "{actor} shared calendar {calendar} with group {group}" : "{actor} delade kalender {calendar} med grupp {group}",
    "You unshared calendar {calendar} from group {group}" : "Du slutade dela kalender {calendar} med gruppen {group}",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor} slutade dela kalender {calendar} med gruppen {group}",
    "{actor} created event {event} in calendar {calendar}" : "{actor} skapade händelse {event} i kalender {calendar}",
    "You created event {event} in calendar {calendar}" : "Du skapade händelse {event} i kalender {calendar}",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor} raderade händelse {event} från kalender {calendar}",
    "You deleted event {event} from calendar {calendar}" : "Du raderade händelse {event} från kalender {calendar}",
    "{actor} updated event {event} in calendar {calendar}" : "{actor} uppdaterade händelse {event} i kalender {calendar}",
    "You updated event {event} in calendar {calendar}" : "Du uppdaterade händelse {event} i kalender {calendar}",
    "{actor} created todo {todo} in list {calendar}" : "{actor} skapade uppgift {todo} i listan {calendar}",
    "You created todo {todo} in list {calendar}" : "Du skapade uppgift {todo} i listan {calendar}",
    "{actor} deleted todo {todo} from list {calendar}" : "{actor} raderade uppgift {todo} från listan {calendar}",
    "You deleted todo {todo} from list {calendar}" : "Du raderade uppgift {todo} från listan {calendar}",
    "{actor} updated todo {todo} in list {calendar}" : "{actor} uppdaterade uppgift {todo} i listan {calendar}",
    "You updated todo {todo} in list {calendar}" : "Du uppdaterade uppgift {todo} i listan {calendar}",
    "{actor} solved todo {todo} in list {calendar}" : "{actor} löste uppgift {todo} i listan {calendar}",
    "You solved todo {todo} in list {calendar}" : "Du löste uppgift {todo} i listan {calendar}",
    "{actor} reopened todo {todo} in list {calendar}" : "{actor} återupptog uppgift {todo} i listan {calendar}",
    "You reopened todo {todo} in list {calendar}" : "Du återupptog uppgift {todo} i listan {calendar}",
    "A <strong>calendar</strong> was modified" : "En <strong>kalender</strong> modifierades",
    "A calendar <strong>event</strong> was modified" : "En kalender-<strong>händelse</strong> modifierades",
    "A calendar <strong>todo</strong> was modified" : "En kalender <strong>uppgift</strong> modifierades",
    "Contact birthdays" : "Födelsedagar",
    "Contacts" : "Kontakter",
    "Technical details" : "Tekniska detaljer",
    "Remote Address: %s" : "Extern adress: %s",
    "Request ID: %s" : "Begär ID: %s"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-13.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/dav/l10n/sv.js <==
OC.L10N.register(
    "dav",
    {
    "Calendar" : "Kalender",
    "Todos" : "Uppgifter",
    "Personal" : "Privat",
    "{actor} created calendar {calendar}" : "{actor} skapade kalender {calendar}",
    "You created calendar {calendar}" : "Du skapade kalender {calendar}",
    "{actor} deleted calendar {calendar}" : "{actor} raderade kalender {calendar}",
    "You deleted calendar {calendar}" : "Du raderade kalender {calendar}",
    "{actor} updated calendar {calendar}" : "{actor} uppdaterade kalender {calendar}",
    "You updated calendar {calendar}" : "Du uppdaterade kalender {calendar}",
    "You shared calendar {calendar} as public link" : "Du delade kalender {calendar} som offentlig länk",
    "You removed public link for calendar {calendar}" : "Du tog bort offentlig länk för kalender {calendar}",
    "{actor} shared calendar {calendar} with you" : "{actor} delade kalender {calendar} med dig",
    "You shared calendar {calendar} with {user}" : "Du delade kalender {calendar} med {user}",
    "{actor} shared calendar {calendar} with {user}" : "{actor} delade kalender {calendar} med {user}",
    "{actor} unshared calendar {calendar} from you" : "{actor} slutade dela kalender {calendar} med dig",
    "You unshared calendar {calendar} from {user}" : "Du slutade dela kalender {calendar} med {user}",
    "{actor} unshared calendar {calendar} from {user}" : "{actor} slutade dela kalender {calendar} med {user}",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} slutade dela kalender {calendar} med sig själv",
    "You shared calendar {calendar} with group {group}" : "Du delade kalender {calendar} med grupp {group}",
    "{actor} shared calendar {calendar} with group {group}" : "{actor} delade kalender {calendar} med grupp {group}",
    "You unshared calendar {calendar} from group {group}" : "Du slutade dela kalender {calendar} med gruppen {group}",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor} slutade dela kalender {calendar} med gruppen {group}",
    "{actor} created event {event} in calendar {calendar}" : "{actor} skapade händelse {event} i kalender {calendar}",
    "You created event {event} in calendar {calendar}" : "Du skapade händelse {event} i kalender {calendar}",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor} raderade händelse {event} från kalender {calendar}",
    "You deleted event {event} from calendar {calendar}" : "Du raderade händelse {event} från kalender {calendar}",
    "{actor} updated event {event} in calendar {calendar}" : "{actor} uppdaterade händelse {event} i kalender {calendar}",
    "You updated event {event} in calendar {calendar}" : "Du uppdaterade händelse {event} i kalender {calendar}",
    "{actor} created todo {todo} in list {calendar}" : "{actor} skapade uppgift {todo} i listan {calendar}",
    "You created todo {todo} in list {calendar}" : "Du skapade uppgift {todo} i listan {calendar}",
    "{actor} deleted todo {todo} from list {calendar}" : "{actor} raderade uppgift {todo} från listan {calendar}",
    "You deleted todo {todo} from list {calendar}" : "Du raderade uppgift {todo} från listan {calendar}",
    "{actor} updated todo {todo} in list {calendar}" : "{actor} uppdaterade uppgift {todo} i listan {calendar}",
    "You updated todo {todo} in list {calendar}" : "Du uppdaterade uppgift {todo} i listan {calendar}",
    "{actor} solved todo {todo} in list {calendar}" : "{actor} löste uppgift {todo} i listan {calendar}",
    "You solved todo {todo} in list {calendar}" : "Du löste uppgift {todo} i listan {calendar}",
    "{actor} reopened todo {todo} in list {calendar}" : "{actor} återupptog uppgift {todo} i listan {calendar}",
    "You reopened todo {todo} in list {calendar}" : "Du återupptog uppgift {todo} i listan {calendar}",
    "A <strong>calendar</strong> was modified" : "En <strong>kalender</strong> modifierades",
    "A calendar <strong>event</strong> was modified" : "En kalender-<strong>händelse</strong> modifierades",
    "A calendar <strong>todo</strong> was modified" : "En kalender <strong>uppgift</strong> modifierades",
    "Contact birthdays" : "Födelsedagar",
    "%s via %s" : "%s via %s",
    "Invitation canceled" : "Inbjudan avbruten",
    "Hello %s," : "He %s,",
    "The meeting »%s« with %s was canceled." : "Mötet »%s« med%s avbröts.",
    "Invitation updated" : "Inbjudan uppdaterad",
    "The meeting »%s« with %s was updated." : "Mötet »%s« med %s uppdaterades.",
    "%s invited you to »%s«" : "%s bjöd in dig till »%s«",
    "When:" : "När",
    "Where:" : "Var:",
    "Description:" : "Beskrivning:",
    "Link:" : "Länk:",
    "Contacts" : "Kontakter",
    "Technical details" : "Tekniska detaljer",
    "Remote Address: %s" : "Extern adress: %s",
    "Request ID: %s" : "Begär ID: %s",
    "CalDAV server" : "CalDAV server",
    "Send invitations to attendees" : "Skicka inbjudan till deltagare",
    "Please make sure to properly set up the email settings above." : "Vänligen säkerställ att epost-inställningarna ovan är korrekt angivna",
    "Automatically generate a birthday calendar" : "Generera en födelsedagskalender automatiskt",
    "Birthday calendars will be generated by a background job." : "Födelsedagskalender kommer skapas som ett bakgrundsjobb."
},
"nplurals=2; plural=(n != 1);");
